import {
  Entity,
  PrimaryGeneratedColumn,
  Column,
  CreateDateColumn,
  UpdateDateColumn,
  OneToMany,
  ManyToMany,
  JoinTable,
  ManyToOne,
} from 'typeorm';
import { Message } from './message.entity';
import { User } from './user.entity';
import { Organization } from './organization.entity';

export enum ChatRoomType {
  DIRECT = 'direct',
  GROUP = 'group',
}

@Entity('chat_rooms')
export class ChatRoom {
  @PrimaryGeneratedColumn('uuid')
  id: string;

  @Column({ nullable: true })
  name: string;

  @Column({ type: 'text', nullable: true })
  description: string;

  @Column({
    type: 'varchar',
    enum: ChatRoomType,
    default: ChatRoomType.DIRECT,
  })
  type: ChatRoomType;

  @Column({ nullable: true })
  avatar: string;

  @Column({ default: false })
  isEncrypted: boolean;

  @Column({ type: 'text', nullable: true })
  encryptionKey: string;

  @ManyToOne(() => User, { nullable: true })
  createdBy: User;

  @ManyToOne(() => Organization)
  organization: Organization;

  @CreateDateColumn()
  createdAt: Date;

  @UpdateDateColumn()
  updatedAt: Date;

  @OneToMany(() => Message, (message) => message.chatRoom)
  messages: Message[];

  @ManyToMany(() => User, (user) => user.chatRooms)
  @JoinTable({
    name: 'chat_room_members',
    joinColumn: { name: 'chatRoomId', referencedColumnName: 'id' },
    inverseJoinColumn: { name: 'userId', referencedColumnName: 'id' },
  })
  members: User[];
}