import {
  Entity,
  PrimaryGeneratedColumn,
  Column,
  CreateDateColumn,
  UpdateDateColumn,
  ManyToOne,
  OneToMany,
} from 'typeorm';
import { User } from './user.entity';
import { ChatRoom } from './chat-room.entity';
import { MessageMedia } from './message-media.entity';
import { MessageMention } from './message-mention.entity';
import { Organization } from './organization.entity';

export enum MessageType {
  TEXT = 'text',
  IMAGE = 'image',
  VIDEO = 'video',
  AUDIO = 'audio',
  FILE = 'file',
  SYSTEM = 'system',
}

@Entity('messages')
export class Message {
  @PrimaryGeneratedColumn('uuid')
  id: string;

  @Column({ type: 'text' })
  content: string;

  @Column({
    type: 'varchar',
    enum: MessageType,
    default: MessageType.TEXT,
  })
  type: MessageType;

  @Column({ default: false })
  isEncrypted: boolean;

  @Column({ type: 'text', nullable: true })
  encryptedContent: string;

  @Column({ default: false })
  isEdited: boolean;

  @Column({ default: false })
  isDeleted: boolean;

  @Column({ type: 'datetime', nullable: true })
  editedAt: Date;

  @CreateDateColumn()
  createdAt: Date;

  @UpdateDateColumn()
  updatedAt: Date;

  @ManyToOne(() => User, (user) => user.messages)
  sender: User;

  @ManyToOne(() => ChatRoom, (chatRoom) => chatRoom.messages)
  chatRoom: ChatRoom;

  @ManyToOne(() => Organization)
  organization: Organization;

  @OneToMany(() => MessageMedia, (media) => media.message)
  media: MessageMedia[];

  @OneToMany(() => MessageMention, (mention) => mention.message)
  mentions: MessageMention[];

  @Column('uuid', { nullable: true })
  replyToId: string;

  @ManyToOne(() => Message, { nullable: true })
  replyTo: Message;
}