import {
  Entity,
  PrimaryGeneratedColumn,
  Column,
  CreateDateColumn,
  ManyToOne,
} from 'typeorm';
import { User } from './user.entity';
import { Message } from './message.entity';
import { Organization } from './organization.entity';

export enum NotificationType {
  MESSAGE = 'message',
  MENTION = 'mention',
  GROUP_INVITE = 'group_invite',
  FRIEND_REQUEST = 'friend_request',
  ORGANIZATION_INVITE = 'organization_invite',
}

@Entity('notifications')
export class Notification {
  @PrimaryGeneratedColumn('uuid')
  id: string;

  @Column({
    type: 'varchar',
    enum: NotificationType,
  })
  type: NotificationType;

  @Column()
  title: string;

  @Column({ type: 'text' })
  body: string;

  @Column({ type: 'json', nullable: true })
  data: any;

  @Column({ default: false })
  isRead: boolean;

  @Column({ default: false })
  isSent: boolean;

  @CreateDateColumn()
  createdAt: Date;

  @ManyToOne(() => User)
  recipient: User;

  @ManyToOne(() => Message, { nullable: true })
  message: Message;

  @ManyToOne(() => Organization)
  organization: Organization;
}