import {
  Entity,
  PrimaryGeneratedColumn,
  Column,
  CreateDateColumn,
  UpdateDateColumn,
  OneToMany,
  ManyToOne,
} from 'typeorm';
import { User } from './user.entity';
import { OrganizationMember } from './organization-member.entity';
import { OrganizationInvite } from './organization-invite.entity';

export enum OrganizationPlan {
  FREE = 'free',
  BASIC = 'basic',
  PREMIUM = 'premium',
  ENTERPRISE = 'enterprise',
}

export enum OrganizationStatus {
  ACTIVE = 'active',
  SUSPENDED = 'suspended',
  DELETED = 'deleted',
}

@Entity('organizations')
export class Organization {
  @PrimaryGeneratedColumn('uuid')
  id: string;

  @Column({ unique: true })
  name: string;

  @Column({ unique: true })
  slug: string;

  @Column({ type: 'text', nullable: true })
  description: string;

  @Column({ nullable: true })
  logo: string;

  @Column({ nullable: true })
  website: string;

  @Column({ nullable: true })
  contactEmail: string;

  @Column({
    type: 'varchar',
    enum: OrganizationPlan,
    default: OrganizationPlan.FREE,
  })
  plan: OrganizationPlan;

  @Column({
    type: 'varchar',
    enum: OrganizationStatus,
    default: OrganizationStatus.ACTIVE,
  })
  status: OrganizationStatus;

  @Column({ type: 'json', nullable: true })
  settings: {
    allowPublicSignup?: boolean;
    requireInviteApproval?: boolean;
    maxMembers?: number;
    allowFileUploads?: boolean;
    maxFileSize?: number;
    enableEncryption?: boolean;
    customBranding?: boolean;
  };

  @Column({ type: 'json', nullable: true })
  limits: {
    maxUsers?: number;
    maxChatRooms?: number;
    maxFileStorage?: number; // in bytes
    maxMonthlyMessages?: number;
  };

  @Column({ type: 'datetime', nullable: true })
  subscriptionExpiry: Date;

  @ManyToOne(() => User)
  owner: User;

  @CreateDateColumn()
  createdAt: Date;

  @UpdateDateColumn()
  updatedAt: Date;

  @OneToMany(() => OrganizationMember, (member) => member.organization)
  members: OrganizationMember[];

  @OneToMany(() => OrganizationInvite, (invite) => invite.organization)
  invites: OrganizationInvite[];
}