import { Injectable } from '@nestjs/common';
import * as CryptoJS from 'crypto-js';
import { randomBytes } from 'crypto';

@Injectable()
export class EncryptionService {
  encryptMessage(message: string, key: string): string {
    return CryptoJS.AES.encrypt(message, key).toString();
  }

  decryptMessage(encryptedMessage: string, key: string): string {
    const bytes = CryptoJS.AES.decrypt(encryptedMessage, key);
    return bytes.toString(CryptoJS.enc.Utf8);
  }

  generateChatRoomKey(): string {
    return randomBytes(32).toString('hex');
  }

  encryptWithPublicKey(message: string, publicKey: string): string {
    // In a real implementation, you would use RSA encryption
    // For simplicity, we're using AES encryption with the public key as the secret
    return CryptoJS.AES.encrypt(message, publicKey).toString();
  }

  decryptWithPrivateKey(encryptedMessage: string, privateKey: string): string {
    // In a real implementation, you would use RSA decryption
    // For simplicity, we're using AES decryption with the private key as the secret
    const bytes = CryptoJS.AES.decrypt(encryptedMessage, privateKey);
    return bytes.toString(CryptoJS.enc.Utf8);
  }
}

export function generateKeyPair(): { publicKey: string; privateKey: string } {
  // In a real implementation, you would generate RSA key pairs
  // For simplicity, we're generating random keys
  const publicKey = randomBytes(32).toString('hex');
  const privateKey = randomBytes(32).toString('hex');
  
  return { publicKey, privateKey };
}