import { IsOptional, IsString, IsObject, IsUrl, IsEmail, Length, Matches } from 'class-validator';
import { ApiProperty } from '@nestjs/swagger';
import { OrganizationPlan } from '../../database/entities/organization.entity';

export class UpdateOrganizationDto {
  @ApiProperty({ required: false })
  @IsOptional()
  @IsString()
  @Length(2, 100)
  name?: string;

  @ApiProperty({ required: false })
  @IsOptional()
  @IsString()
  @Length(2, 50)
  @Matches(/^[a-z0-9-]+$/, { message: 'Slug can only contain lowercase letters, numbers, and hyphens' })
  slug?: string;

  @ApiProperty({ required: false })
  @IsOptional()
  @IsString()
  @Length(0, 500)
  description?: string;

  @ApiProperty({ required: false })
  @IsOptional()
  @IsUrl()
  website?: string;

  @ApiProperty({ required: false })
  @IsOptional()
  @IsEmail()
  contactEmail?: string;

  @ApiProperty({ required: false, enum: OrganizationPlan })
  @IsOptional()
  @IsString()
  plan?: OrganizationPlan;

  @ApiProperty({ required: false })
  @IsOptional()
  @IsObject()
  settings?: {
    allowPublicSignup?: boolean;
    requireInviteApproval?: boolean;
    maxMembers?: number;
    allowFileUploads?: boolean;
    maxFileSize?: number;
    enableEncryption?: boolean;
    customBranding?: boolean;
  };

  @ApiProperty({ required: false })
  @IsOptional()
  @IsObject()
  limits?: {
    maxUsers?: number;
    maxChatRooms?: number;
    maxFileStorage?: number;
    maxMonthlyMessages?: number;
  };
}